#
#  engine
#
#  Playout Daemon for autoradio project
#
#
#  Copyright (C) 2017-2018 Gottfried Gaisbauer <gottfried.gaisbauer@servus.at>
#
#  This file is part of engine.
#
#  engine is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  any later version.
#
#  engine is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with engine. If not, see <http://www.gnu.org/licenses/>.
#

import smtplib
from email.message import EmailMessage
from libraries.exceptions.auraexceptions import MailingException


class AuraMailer():
    config = None

    # ------------------------------------------------------------------------------------------ #
    def __init__(self, config):
        self.config = config
        self.admin_mails = config.get("admin_mail")

    # ------------------------------------------------------------------------------------------ #
    def send_admin_mail(self, subject, body):
        admin_mails = self.admin_mails.split()

        for mail_to in admin_mails:
            self.__send(mail_to, subject, body)

    # ------------------------------------------------------------------------------------------ #
    def __send(self, mail_to, subject, body):
        # read config
        mail_server = self.config.get("mail_server")
        mail_port = self.config.get("mail_server_port")
        mail_user = self.config.get("mail_user")
        mail_pass = self.config.get("mail_pass")
        from_mail = self.config.get("from_mail")

        # check settings
        if mail_server == "":
            raise MailingException("Mail Server not set")
        if mail_port == "":
            raise MailingException("Mailserver Port not set")
        if mail_user == "":
            raise MailingException("Mail user not set")
        if mail_pass == "":
            raise MailingException("No Password for mailing set")
        if from_mail == "":
            raise MailingException("From Mail not set")

        # stuff the message together and ...
        msg = EmailMessage()
        msg.set_content(body)
        mailsubject_prefix = self.config.get("mailsubject_prefix")
        if mailsubject_prefix == "":
            msg["Subject"] = subject
        else:
            msg["Subject"] = mailsubject_prefix + " " + subject
        msg["From"] = from_mail
        msg["To"] = mail_to

        # ... send the mail
        try:
            server = smtplib.SMTP(mail_server, int(mail_port))
            server.starttls()
            server.login(mail_user, mail_pass)
            server.send_message(msg)
            server.quit()
        except Exception as e:
            raise MailingException(str(e))
